==> labplot_1.3.1.1.orig.tar.gz: labplot-1.3.1.orig/src/FilterAUDIOFILE.cc <==
//LabPlot : FilterAUDIOFILE.cc

#include <klocale.h>
#include <kdebug.h>

#include "FilterAUDIOFILE.h"

#define BUFFER_FRAMES 4096

FilterAUDIOFILE::FilterAUDIOFILE(QString filename)
	: filename(filename)
{
	if(filename.length()>0) {
		file = afOpenFile(filename, "r", NULL);
	
		if (file == AF_NULL_FILEHANDLE)		// not an audio file or not readable
			fileok=FALSE;
		else {
			fileok=TRUE;
		
			format=afGetFileFormat(file,0);
		}
	}
}

QString FilterAUDIOFILE::getFormat(int f) {
	switch(f) {
	case AF_FILE_UNKNOWN: return QString("AF_FILE_UNKNOWN"); break;
	case AF_FILE_RAWDATA: return QString("AF_FILE_RAWDATA"); break;
	case AF_FILE_AIFFC: return QString("AF_FILE_AIFFC"); break;
	case AF_FILE_AIFF: return QString("AF_FILE_AIFF"); break;
	case AF_FILE_NEXTSND: return QString("AF_FILE_NEXTSND"); break;
	case AF_FILE_WAVE: return QString("AF_FILE_WAVE"); break;
	case AF_FILE_BICSF: return QString("AF_FILE_BICSF/AF_FILE_IRCAM"); break;
	}

	return 0;
}
 
double *FilterAUDIOFILE::getData() {
	int format, width;
	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
	
	int size = frameCount()*channelCount();
	double *data = new double[size];
	
	switch(format) {
	case AF_SAMPFMT_UNSIGNED:	// unsigned
		switch(width) {
		case 8: {		// 8 bit
			unsigned char *buffer = new unsigned char[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++) {
				// TODO : explain this
				data[i] = buffer[i]-128;
				//kdDebug()<<" x/y "<<i<<'/'<<data[2*i]<<" "<<data[2*i+1]<<endl;
			}
			for(int i=0;i<100;i++)
				kdDebug()<<" 1/2 : "<<data[2*i]<<'/'<<data[2*i+1]<<endl;
			}
			break;
		case 16: {			
			unsigned short *buffer = new unsigned short[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++) {
				// TODO : explain this
				data[i] = buffer[i]-128;
				//kdDebug()<<" x/y "<<i<<'/'<<y<<endl;
			}
			}
			break;
		}
		break;
	case AF_SAMPFMT_TWOSCOMP:	// signed "two's complement"
		switch(width) {
		case 8: {		// 8 bit
			char *buffer = new char[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++)
				data[i] = buffer[i];
			}
			break;
		case 16: {	// 16 bit
			short *buffer = new short[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++)
				data[i] = buffer[i];
			}
			break;
		}
		break;
	}
	return data;
 }
 
 QString FilterAUDIOFILE::sampleFormat() {
	int format, width;
	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
	
	switch(format) {
	case AF_SAMPFMT_TWOSCOMP:
		return i18n("two's complement");break;
	case AF_SAMPFMT_UNSIGNED:
		return i18n("unsigned");break;
	case AF_SAMPFMT_FLOAT:
		return i18n("float");break;
	case AF_SAMPFMT_DOUBLE:
		return i18n("double");break;
		
	}
		
	return i18n("UNKNOWN");
}

int FilterAUDIOFILE::sampleWidth() {
	int format, width;
	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
	
	return width;
}

==> labplot_1.5.0.5.orig.tar.gz: labplot-1.5.0.orig/src/FilterAUDIOFILE.cc <==
//LabPlot : FilterAUDIOFILE.cc

#include <klocale.h>
#include <kdebug.h>

#include "FilterAUDIOFILE.h"

#define BUFFER_FRAMES 4096

FilterAUDIOFILE::FilterAUDIOFILE(QString filename)
	: filename(filename)
{
	if(filename.length()>0) {
		file = afOpenFile(filename, "r", NULL);
	
		if (file == AF_NULL_FILEHANDLE)		// not an audio file or not readable
			fileok=false;
		else {
			fileok=true;
		
			format=afGetFileFormat(file,0);
		}
	}
}

QString FilterAUDIOFILE::Format(int f) {
	switch(f) {
	case AF_FILE_UNKNOWN: return QString("AF_FILE_UNKNOWN"); break;
	case AF_FILE_RAWDATA: return QString("AF_FILE_RAWDATA"); break;
	case AF_FILE_AIFFC: return QString("AF_FILE_AIFFC"); break;
	case AF_FILE_AIFF: return QString("AF_FILE_AIFF"); break;
	case AF_FILE_NEXTSND: return QString("AF_FILE_NEXTSND"); break;
	case AF_FILE_WAVE: return QString("AF_FILE_WAVE"); break;
	case AF_FILE_BICSF: return QString("AF_FILE_BICSF/AF_FILE_IRCAM"); break;
	}

	return 0;
}
 
double *FilterAUDIOFILE::Data() {
	int format, width;
	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
	
	int size = frameCount()*channelCount();
	double *data = new double[size];
	
	switch(format) {
	case AF_SAMPFMT_UNSIGNED:	// unsigned
		switch(width) {
		case 8: {		// 8 bit
			unsigned char *buffer = new unsigned char[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++) {
				// TODO : explain this
				data[i] = buffer[i]-128;
				//kdDebug()<<" x/y "<<i<<'/'<<data[2*i]<<" "<<data[2*i+1]<<endl;
			}
			for(int i=0;i<100;i++)
				kdDebug()<<" 1/2 : "<<data[2*i]<<'/'<<data[2*i+1]<<endl;
			}
			break;
		case 16: {			
			unsigned short *buffer = new unsigned short[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++) {
				// TODO : explain this
				data[i] = buffer[i]-128;
				//kdDebug()<<" x/y "<<i<<'/'<<y<<endl;
			}
			}
			break;
		}
		break;
	case AF_SAMPFMT_TWOSCOMP:	// signed "two's complement"
		switch(width) {
		case 8: {		// 8 bit
			char *buffer = new char[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++)
				data[i] = buffer[i];
			}
			break;
		case 16: {	// 16 bit
			short *buffer = new short[size];
			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);

			for(int i=0;i<size;i++)
				data[i] = buffer[i];
			}
			break;
		}
		break;
	}
	return data;
 }
 
 QString FilterAUDIOFILE::sampleFormat() {
	int format, width;
	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
	
	switch(format) {
	case AF_SAMPFMT_TWOSCOMP:
		return i18n("two's complement");break;
	case AF_SAMPFMT_UNSIGNED:
		return i18n("unsigned");break;
	case AF_SAMPFMT_FLOAT:
		return i18n("float");break;
	case AF_SAMPFMT_DOUBLE:
		return i18n("double");break;
		
	}
		
	return i18n("UNKNOWN");
}

int FilterAUDIOFILE::sampleWidth() {
	int format, width;
	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
	
	return width;
}
